@@ -48,7 +48,6 @@ public:
     AbstractMetaFunctionPrivate()
         : m_constant(false),
           m_reverse(false),
-          m_explicit(false),
           m_pointerOperator(false),
           m_isCallOperator(false)
     {
@@ -87,10 +86,10 @@ public:
     AddedFunctionPtr m_addedFunction;
     SourceLocation m_sourceLocation;
     AbstractMetaFunction::Attributes m_attributes;
+    FunctionAttributes m_cppAttributes;
     AbstractMetaFunction::Flags m_flags;
     uint m_constant                 : 1;
     uint m_reverse                  : 1;
-    uint m_explicit                 : 1;
     uint m_pointerOperator          : 1;
     uint m_isCallOperator           : 1;
     mutable int m_cachedOverloadNumber = TypeSystem::OverloadNumberUnset;
@@ -120,9 +119,9 @@ AbstractMetaFunction::AbstractMetaFunction(const AddedFunctionPtr &addedFunc) :
         setAccess(Access::Public);
         break;
     }
-    AbstractMetaFunction::Attributes atts = AbstractMetaFunction::FinalInTargetLang;
+    AbstractMetaFunction::Attributes atts;
     if (addedFunc->isStatic())
-        atts |= AbstractMetaFunction::Static;
+        setCppAttribute(FunctionAttribute::Static);
     if (addedFunc->isClassMethod())
         atts |= AbstractMetaFunction::ClassMethod;
     setAttributes(atts);
@@ -215,12 +214,12 @@ void AbstractMetaFunction::setPointerOperator(bool value)
 
 bool AbstractMetaFunction::isExplicit() const
 {
-    return d->m_explicit;
+    return d->m_cppAttributes.testFlag(FunctionAttribute::Explicit);
 }
 
 void AbstractMetaFunction::setExplicit(bool isExplicit)
 {
-    d->m_explicit = isExplicit;
+    d->m_cppAttributes.setFlag(FunctionAttribute::Explicit, isExplicit);
 }
 
 bool AbstractMetaFunction::returnsBool() const
@@ -262,6 +261,21 @@ void AbstractMetaFunction::operator-=(AbstractMetaFunction::Attribute attribute)
     d->m_attributes.setFlag(attribute, false);
 }
 
+FunctionAttributes AbstractMetaFunction::cppAttributes() const
+{
+    return d->m_cppAttributes;
+}
+
+void AbstractMetaFunction::setCppAttributes(FunctionAttributes a)
+{
+    d->m_cppAttributes = a;
+}
+
+void AbstractMetaFunction::setCppAttribute(FunctionAttribute a, bool on)
+{
+    d->m_cppAttributes.setFlag(a, on);
+}
+
 AbstractMetaFunction::Flags AbstractMetaFunction::flags() const
 {
     return d->m_flags;
@@ -275,27 +289,28 @@ void AbstractMetaFunction::setFlags(Flags f)
 /*******************************************************************************
  * Indicates that this function has a modification that removes it
  */
+
+static bool fmIsRemoved(const FunctionModification &mod) { return mod.isRemoved(); }
+
 bool AbstractMetaFunction::isModifiedRemoved(AbstractMetaClassCPtr cls) const
 {
     if (!isInGlobalScope() && !cls)
         cls = d->m_implementingClass;
-    for (const auto &mod : modifications(cls)) {
-        if (mod.isRemoved())
-            return true;
-    }
+    const auto &mods = modifications(cls);
+    return std::any_of(mods.cbegin(), mods.cend(), fmIsRemoved);
+}
 
-    return false;
+static bool isFinal(const FunctionModification &mod)
+{
+    return mod.modifiers().testFlag(FunctionModification::Final);
 }
 
 bool AbstractMetaFunction::isModifiedFinal(AbstractMetaClassCPtr cls) const
 {
     if (!isInGlobalScope() && cls == nullptr)
         cls = d->m_implementingClass;
-    for (const auto &mod : modifications(cls)) {
-        if (mod.modifiers().testFlag(FunctionModification::Final))
-            return true;
-    }
-    return false;
+    const auto &mods = modifications(cls);
+    return std::any_of(mods.cbegin(), mods.cend(), isFinal);
 }
 
 bool AbstractMetaFunction::isVoid() const
@@ -342,7 +357,7 @@ AbstractMetaFunction::CompareResult AbstractMetaFunction::compareTo(const Abstra
         result |= EqualImplementor;
 
     // Attributes
-    if (attributes() == other->attributes())
+    if (attributes() == other->attributes() && cppAttributes() == other->cppAttributes())
         result |= EqualAttributes;
 
     // Compare types
@@ -409,7 +424,7 @@ bool AbstractMetaFunction::isConstOverloadOf(const AbstractMetaFunction *other)
     }
 
     // Match "const Foo &getFoo() const" / "Foo &getFoo()" / "Foo getFoo() const"
-    const auto otherType = other->type();
+    const auto &otherType = other->type();
     if (d->m_type.name() != otherType.name()
         || d->m_type.indirectionsV() != otherType.indirectionsV()) {
         return false;
@@ -427,6 +442,10 @@ AbstractMetaFunction *AbstractMetaFunction::copy() const
 {
     auto *cpy = new AbstractMetaFunction;
     cpy->setAttributes(attributes());
+    auto ca = cppAttributes();
+    // Historical bug: explicit was not copied! (causing nontypetemplate_test.py fail)
+    ca.setFlag(FunctionAttribute::Explicit, false);
+    cpy->setCppAttributes(ca);
     cpy->setFlags(flags());
     cpy->setAccess(access());
     cpy->setName(name());
@@ -447,17 +466,17 @@ AbstractMetaFunction *AbstractMetaFunction::copy() const
     return cpy;
 }
 
+static bool usesRValueReference(const AbstractMetaArgument &a)
+{
+    return a.type().referenceType() == RValueReference;
+}
+
 bool AbstractMetaFunction::usesRValueReferences() const
 {
-    if (d->m_functionType == MoveConstructorFunction || d->m_functionType == MoveAssignmentOperatorFunction)
-        return true;
-    if (d->m_type.referenceType() == RValueReference)
-        return true;
-    for (const AbstractMetaArgument &a : d->m_arguments) {
-        if (a.type().referenceType() == RValueReference)
-            return true;
-    }
-    return false;
+    return d->m_functionType == MoveConstructorFunction
+        || d->m_functionType == MoveAssignmentOperatorFunction
+        || d->m_type.referenceType() == RValueReference
+        || std::any_of(d->m_arguments.cbegin(), d->m_arguments.cend(), usesRValueReference);
 }
 
 bool AbstractMetaFunction::generateBinding() const
@@ -524,7 +543,8 @@ QString AbstractMetaFunctionPrivate::signature() const
                 m_cachedSignature += u", "_s;
             m_cachedSignature += t.cppSignature();
             // We need to have the argument names in the qdoc files
-            m_cachedSignature += u' ';
+            if (!m_cachedSignature.endsWith(u'*') && !m_cachedSignature.endsWith(u'&'))
+                m_cachedSignature += u' ';
             m_cachedSignature += a.name();
         }
         m_cachedSignature += u')';
@@ -574,6 +594,11 @@ bool AbstractMetaFunction::isUserAdded() const
     return d->m_addedFunction && !d->m_addedFunction->isDeclaration();
 }
 
+bool AbstractMetaFunction::isUserAddedPythonOverride() const
+{
+    return d->m_addedFunction && d->m_addedFunction->isPythonOverride();
+}
+
 bool AbstractMetaFunction::isUserDeclared() const
 {
     return d->m_addedFunction && d->m_addedFunction->isDeclaration();
@@ -630,7 +655,7 @@ ArgumentOwner AbstractMetaFunction::argumentOwner(const AbstractMetaClassCPtr &c
             return argumentMod.owner();
         }
     }
-    return ArgumentOwner();
+    return {};
 }
 
 QString AbstractMetaFunction::conversionRule(TypeSystem::Language language, int key) const
@@ -647,7 +672,7 @@ QString AbstractMetaFunction::conversionRule(TypeSystem::Language language, int
         }
     }
 
-    return QString();
+    return {};
 }
 
 bool AbstractMetaFunction::hasConversionRule(TypeSystem::Language language, int idx) const
@@ -711,6 +736,11 @@ void AbstractMetaFunction::setArguments(const AbstractMetaArgumentList &argument
     d->m_arguments = arguments;
 }
 
+void AbstractMetaFunction::setArgumentName(qsizetype a, const QString &name)
+{
+    d->m_arguments[a].setName(name);
+}
+
 void AbstractMetaFunction::addArgument(const AbstractMetaArgument &argument)
 {
     d->m_arguments << argument;
@@ -729,7 +759,8 @@ static bool modifiedUndeprecated(const FunctionModification &mod)
 bool AbstractMetaFunction::isDeprecated() const
 {
     const auto &mods = modifications(declaringClass());
-    return d->m_attributes.testFlag(Attribute::Deprecated)
+
+    return d->m_cppAttributes.testFlag(FunctionAttribute::Deprecated)
            ? std::none_of(mods.cbegin(), mods.cend(), modifiedUndeprecated)
            : std::any_of(mods.cbegin(), mods.cend(), modifiedDeprecated);
 }
@@ -938,7 +969,8 @@ void AbstractMetaFunction::applyTypeModifications()
                 && !d->applyTypeModification(this, am.modifiedType(),
                                              n, &errorMessage)) {
                 throw Exception(errorMessage);
-            } else if (am.isRemoved() && n != 0) {
+            }
+            if (am.isRemoved() && n != 0) {
                 if (n < 1 || n > d->m_arguments.size()) {
                     errorMessage =
                         msgArgumentRemovalFailed(this, n,
@@ -1020,9 +1052,10 @@ QString AbstractMetaFunction::signatureComment() const
 QString AbstractMetaFunction::debugSignature() const
 {
     QString result;
-    const bool isOverride = attributes() & AbstractMetaFunction::OverriddenCppMethod;
-    const bool isFinal = attributes() & AbstractMetaFunction::FinalCppMethod;
-    if (!isOverride && !isFinal && (attributes() & AbstractMetaFunction::VirtualCppMethod))
+    const auto attributes = cppAttributes();
+    const bool isOverride = attributes.testFlag(FunctionAttribute::Override);
+    const bool isFinal = attributes.testFlag(FunctionAttribute::Final);
+    if (!isOverride && !isFinal && (attributes.testFlag(FunctionAttribute::Virtual)))
         result += u"virtual "_s;
     if (d->m_implementingClass)
         result += d->m_implementingClass->qualifiedCppName() + u"::"_s;
@@ -1087,7 +1120,7 @@ void AbstractMetaFunction::clearModificationsCache()
     d->m_modificationCache.clear();
 }
 
-const DocModificationList AbstractMetaFunction::addedFunctionDocModifications() const
+DocModificationList AbstractMetaFunction::addedFunctionDocModifications() const
 {
     return d->m_addedFunction
         ? d->m_addedFunction->docModifications() : DocModificationList{};
@@ -1095,7 +1128,7 @@ const DocModificationList AbstractMetaFunction::addedFunctionDocModifications()
 
 QString AbstractMetaFunction::argumentName(int index,
                                            bool /* create */,
-                                           AbstractMetaClassCPtr  /* implementor */) const
+                                           const AbstractMetaClassCPtr & /* implementor */) const
 {
     return d->m_arguments[--index].name();
 }
@@ -1120,19 +1153,31 @@ void AbstractMetaFunction::setTypeEntry(const FunctionTypeEntryPtr &typeEntry)
     d->m_typeEntry = typeEntry;
 }
 
+QString AbstractMetaFunction::targetLangPackage() const
+{
+    if (d->m_addedFunction != nullptr)
+        return d->m_addedFunction->targetLangPackage();
+    if (d->m_class != nullptr)
+        return d->m_class->typeEntry()->targetLangPackage();
+    if (d->m_typeEntry != nullptr)
+        return d->m_typeEntry->targetLangPackage();
+    return {};
+}
+
 bool AbstractMetaFunction::isCallOperator() const
 {
     return d->m_name == u"operator()";
 }
 
+static bool isCodeInjection(const FunctionModification &mod)
+{
+    return mod.isCodeInjection();
+}
+
 bool AbstractMetaFunction::hasInjectedCode() const
 {
     const FunctionModificationList &mods = modifications(ownerClass());
-    for (const FunctionModification &mod : mods) {
-        if (mod.isCodeInjection())
-            return true;
-    }
-    return false;
+    return std::any_of(mods.cbegin(), mods.cend(), isCodeInjection);
 }
 
 // Traverse the code snippets, return true if predicate returns true
@@ -1375,7 +1420,7 @@ bool AbstractMetaFunction::isInplaceOperator() const
 
 bool AbstractMetaFunction::isVirtual() const
 {
-    return d->m_attributes.testFlag(AbstractMetaFunction::VirtualCppMethod);
+    return d->m_cppAttributes.testFlag(FunctionAttribute::Virtual);
 }
 
 QString AbstractMetaFunctionPrivate::modifiedName(const AbstractMetaFunction *q) const
@@ -1400,7 +1445,7 @@ QString AbstractMetaFunction::modifiedName() const
 
 AbstractMetaFunctionCPtr
 AbstractMetaFunction::find(const AbstractMetaFunctionCList &haystack,
-                           QStringView needle)
+                           QAnyStringView needle)
 {
     for (const auto &f : haystack) {
         if (f->name() == needle)
@@ -1519,7 +1564,7 @@ bool AbstractMetaFunction::injectedCodeUsesPySelf() const
 bool AbstractMetaFunction::injectedCodeCallsPythonOverride() const
 {
     static const QRegularExpression
-        overrideCallRegexCheck(QStringLiteral(R"(PyObject_Call\s*\(\s*%PYTHON_METHOD_OVERRIDE\s*,)"));
+        overrideCallRegexCheck(R"(PyObject_Call\s*\(\s*%PYTHON_METHOD_OVERRIDE\s*,)"_L1);
     Q_ASSERT(overrideCallRegexCheck.isValid());
     return injectedCodeContains(overrideCallRegexCheck, TypeSystem::CodeSnipPositionAny,
                                 TypeSystem::NativeCode);
@@ -1529,13 +1574,13 @@ bool AbstractMetaFunction::injectedCodeHasReturnValueAttribution(TypeSystem::Lan
 {
     if (language == TypeSystem::TargetLangCode) {
         static const QRegularExpression
-            retValAttributionRegexCheck_target(QStringLiteral(R"(%PYARG_0\s*=[^=]\s*.+)"));
+            retValAttributionRegexCheck_target(R"(%PYARG_0\s*=[^=]\s*.+)"_L1);
         Q_ASSERT(retValAttributionRegexCheck_target.isValid());
         return injectedCodeContains(retValAttributionRegexCheck_target, TypeSystem::CodeSnipPositionAny, language);
     }
 
     static const QRegularExpression
-        retValAttributionRegexCheck_native(QStringLiteral(R"(%0\s*=[^=]\s*.+)"));
+        retValAttributionRegexCheck_native(R"(%0\s*=[^=]\s*.+)"_L1);
     Q_ASSERT(retValAttributionRegexCheck_native.isValid());
     return injectedCodeContains(retValAttributionRegexCheck_native, TypeSystem::CodeSnipPositionAny, language);
 }
@@ -1550,13 +1595,15 @@ bool AbstractMetaFunction::injectedCodeUsesArgument(int argumentIndex) const
                              }, TypeSystem::CodeSnipPositionAny);
 }
 
+static bool isModifiedToPrivate(const FunctionModification &mod)
+{
+    return mod.modifiers().testFlag(FunctionModification::Private);
+}
+
 bool AbstractMetaFunction::isVisibilityModifiedToPrivate() const
 {
-    for (const auto &mod : modifications()) {
-        if (mod.modifiers().testFlag(FunctionModification::Private))
-            return true;
-    }
-    return false;
+    const auto &mods = modifications();
+    return std::any_of(mods.cbegin(), mods.cend(), isModifiedToPrivate);
 }
 
 struct ComparisonOperator
@@ -1633,9 +1680,9 @@ void AbstractMetaFunction::formatDebugVerbose(QDebug &debug) const
         debug << " [userAdded]";
     if (isUserDeclared())
         debug << " [userDeclared]";
-    if (d->m_explicit)
+    if (d->m_cppAttributes.testFlag(FunctionAttribute::Explicit))
         debug << " [explicit]";
-    if (attributes().testFlag(AbstractMetaFunction::Deprecated))
+    if (d->m_cppAttributes.testFlag(FunctionAttribute::Deprecated))
         debug << " [deprecated]";
     if (d->m_pointerOperator)
         debug << " [operator->]";
