@@ -109,7 +109,21 @@ static void writeProtectedEnums(TextStream &s, const AbstractMetaClassCPtr &meta
     }
 }
 
-void HeaderGenerator::generateClass(TextStream &s, const GeneratorContext &classContext)
+void HeaderGenerator::generateClass(TextStream &s, const QString &,
+                                    const GeneratorContext &classContext,
+                                    QList<GeneratorContext> *)
+{
+    doGenerateClass(s, classContext);
+}
+
+void HeaderGenerator::generateSmartPointerClass(TextStream &s,
+                                                const QString &,
+                                                const GeneratorContext &classContext)
+{
+    doGenerateClass(s, classContext);
+}
+
+void HeaderGenerator::doGenerateClass(TextStream &s, const GeneratorContext &classContext) const
 {
     const AbstractMetaClassCPtr metaClass = classContext.metaClass();
 
@@ -128,7 +142,7 @@ void HeaderGenerator::generateClass(TextStream &s, const GeneratorContext &class
 
     // Includes
     s << metaClass->typeEntry()->include() << '\n';
-    for (auto &inst : metaClass->templateBaseClassInstantiations())
+    for (const auto &inst : metaClass->templateBaseClassInstantiations())
         s << inst.typeEntry()->include();
 
     if (classContext.useWrapper())
@@ -198,9 +212,6 @@ void HeaderGenerator::writeWrapperClassDeclaration(TextStream &s,
     const auto typeEntry = metaClass->typeEntry();
     InheritedOverloadSet inheritedOverloads;
 
-    // write license comment
-    s << licenseComment();
-
     // Class
     s << "class " << wrapperName
       << " : public " << metaClass->qualifiedCppName()
@@ -236,8 +247,6 @@ void HeaderGenerator::writeWrapperClassDeclaration(TextStream &s,
         if (generation.testFlag(FunctionGenerationFlag::VirtualMethod))
             maxOverrides++;
     }
-    if (!maxOverrides)
-        maxOverrides = 1;
 
     //destructor
     // PYSIDE-504: When C++ 11 is used, then the destructor must always be declared.
@@ -273,8 +282,13 @@ void *qt_metacast(const char *_clname) override;
     if (usePySideExtensions())
         s << "static void pysideInitQtMetaTypes();\n";
 
-    s << "void resetPyMethodCache();\n"
-        << outdent << "private:\n" << indent;
+    const bool needsMethodCache = useOverrideCaching(metaClass);
+    Q_ASSERT(maxOverrides > 0 || !needsMethodCache);
+
+    if (needsMethodCache)
+        s << "void resetPyMethodCache();\n";
+
+    s << outdent << "private:\n" << indent;
 
     if (!metaClass->userAddedPythonOverrides().isEmpty()) {
         for (const auto &f : metaClass->userAddedPythonOverrides())
@@ -282,8 +296,14 @@ void *qt_metacast(const char *_clname) override;
         s << '\n';
     }
 
-    s << "mutable bool m_PyMethodCache[" << maxOverrides << "];\n"
-      << outdent << "};\n\n";
+    if (needsMethodCache) {
+        s << "mutable bool m_PyMethodCache[" << maxOverrides << "] = {false";
+        for (int i = 1; i < maxOverrides; ++i)
+            s << ", false";
+        s << "};\n";
+    }
+
+    s << outdent << "};\n\n";
 }
 
 // Write an inline wrapper around a function
@@ -292,7 +312,6 @@ void HeaderGenerator::writeMemberFunctionWrapper(TextStream &s,
                                                  const QString &postfix) const
 {
     Q_ASSERT(!func->isConstructor() && !func->isOperatorOverload());
-    s << "inline ";
     s << functionSignature(func, {}, postfix, Generator::OriginalTypeDescription)
       << " { ";
     if (!func->isVoid())
@@ -526,7 +545,7 @@ static qsizetype indexOf(const NameSpaces &nsps, const AbstractMetaClassCPtr &ne
 static void writeNamespaceForwardDeclarationRecursion(TextStream &s, qsizetype idx,
                                                       const NameSpaces &nameSpaces)
 {
-    auto &root = nameSpaces.at(idx);
+    const auto &root = nameSpaces.at(idx);
     s << '\n';
     if (root.nameSpace->isInlineNamespace())
         s << "inline ";
@@ -915,8 +934,10 @@ void HeaderGenerator::writeTypeFunctions(TextStream &s, const QString &typeFunct
 
 void HeaderGenerator::writeProtectedEnumSurrogate(TextStream &s, const AbstractMetaEnum &cppEnum)
 {
-    if (avoidProtectedHack() && cppEnum.isProtected())
-        s << "enum " << protectedEnumSurrogateName(cppEnum) << " {};\n";
+    if (avoidProtectedHack() && cppEnum.isProtected()) {
+        s << "enum " << protectedEnumSurrogateName(cppEnum) << " : " <<
+          cppEnum.underlyingType() << " {};\n";
+    }
 }
 
 void HeaderGenerator::writeSbkTypeFunction(TextStream &s, const AbstractMetaEnum &cppEnum)
