@@ -203,6 +203,8 @@ protected:
     /// instead of only a Python wrapper.
     static bool shouldGenerateCppWrapper(const AbstractMetaClassCPtr &metaClass);
 
+    static bool shouldGenerateMetaObjectFunctions(const AbstractMetaClassCPtr &metaClass);
+
     /// Returns which functions need to be generated into the wrapper class
     static FunctionGeneration functionGeneration(const AbstractMetaFunctionCPtr &func);
 
@@ -250,10 +252,12 @@ protected:
     static QString cpythonBaseName(const AbstractMetaType &type);
     static QString cpythonTypeName(const AbstractMetaClassCPtr &metaClass);
     static QString cpythonTypeName(const TypeEntryCPtr &type);
+    static QString cpythonTypeNameExtSet(const TypeEntryCPtr &type);
+    static QString cpythonTypeNameExtSet(const AbstractMetaType &type);
     static QString cpythonTypeNameExt(const TypeEntryCPtr &type);
-    static QString cpythonTypeNameExt(const AbstractMetaType &type) ;
+    static QString cpythonTypeNameExt(const AbstractMetaType &type);
     static QString cpythonCheckFunction(TypeEntryCPtr type);
-    static QString cpythonCheckFunction(AbstractMetaType metaType);
+    static QString cpythonCheckFunction(const AbstractMetaType &metaType);
     static QString cpythonIsConvertibleFunction(const TypeEntryCPtr &type);
     static QString cpythonIsConvertibleFunction(const AbstractMetaType &metaType);
     static QString cpythonIsConvertibleFunction(const AbstractMetaArgument &metaArg);
@@ -264,6 +268,7 @@ protected:
     static QString cpythonToPythonConversionFunction(const AbstractMetaClassCPtr &metaClass);
     static QString cpythonToPythonConversionFunction(const TypeEntryCPtr &type);
 
+    static QString cpythonConstructorName(const AbstractMetaClassCPtr &metaClass);
     static QString cpythonFunctionName(const AbstractMetaFunctionCPtr &func) ;
     static QString cpythonMethodDefinitionName(const AbstractMetaFunctionCPtr &func);
     static QString cpythonGettersSettersDefinitionName(const AbstractMetaClassCPtr &metaClass);
@@ -276,8 +281,8 @@ protected:
     static QString cpythonSetterFunctionName(const QPropertySpec &property,
                                              const AbstractMetaClassCPtr &metaClass);
     static QString cpythonWrapperCPtr(const AbstractMetaClassCPtr &metaClass,
-                                      const QString &argName = QStringLiteral("self"));
-     static QString cpythonWrapperCPtr(const AbstractMetaType &metaType,
+                                      const QString &argName = QLatin1StringView("self"));
+    static QString cpythonWrapperCPtr(const AbstractMetaType &metaType,
                                       const QString &argName);
     static QString cpythonWrapperCPtr(const TypeEntryCPtr &type, const QString &argName);
 
@@ -310,6 +315,7 @@ protected:
     static bool useOperatorBoolAsNbBool();
     /// Generate implicit conversions of function arguments
     static bool generateImplicitConversions();
+    static QString cppApiVariableNameOld(const QString &moduleName = {});
     static QString cppApiVariableName(const QString &moduleName = QString());
     static QString pythonModuleObjectName(const QString &moduleName = QString());
     static QString convertersVariableName(const QString &moduleName = QString());
@@ -321,6 +327,9 @@ protected:
     static QString getTypeIndexVariableName(TypeEntryCPtr type);
     static QString getTypeIndexVariableName(const AbstractMetaType &type) ;
 
+    /// Collect all type names as an array for initializing the type/name struct.
+    void collectFullTypeNamesArray(QStringList &typeNames);
+
     /// Returns true if the user don't want verbose error messages on the generated bindings.
     static bool verboseErrorMessagesDisabled();
 
@@ -365,7 +374,10 @@ private:
     static QList<AbstractMetaFunctionCList>
         getNumberProtocolOperators(const AbstractMetaClassCPtr &metaClass);
     static BoolCastFunctionOptional getBoolCast(const AbstractMetaClassCPtr &metaClass);
-    static bool classNeedsGetattroFunctionImpl(const AbstractMetaClassCPtr &metaClass);
+    static bool classNeedsGetattroOverloadFunctionImpl(const FunctionGroups &functionGroups);
+    static AttroCheck checkAttroFunctionNeedsImpl(const AbstractMetaClassCPtr &metaClass,
+                                                  const FunctionGroups &functionGroups);
+    static bool isVirtualOverride(const AbstractMetaFunctionCPtr &f);
 
     QString translateTypeForWrapperMethod(const AbstractMetaType &cType,
                                           const AbstractMetaClassCPtr &context,
